@@ -1,4 +1,4 @@
-/*      $Id: compositor.h 23704 2006-11-04 22:36:42Z olivier $
+/*      $Id: compositor.h 27454 2008-08-15 21:45:57Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -43,6 +43,12 @@ void                     compositorRemoveWindow                 (DisplayInfo *,
                                                                  Window);
 void                     compositorDamageWindow                 (DisplayInfo *,
                                                                  Window);
+void                     compositorResizeWindow                 (DisplayInfo *,
+                                                                 Window,
+                                                                 int,
+                                                                 int,
+                                                                 int,
+                                                                 int);
 void                     compositorHandleEvent                  (DisplayInfo *,
                                                                  XEvent *);
 void                     compositorInitDisplay                  (DisplayInfo *);
