@@ -1,4 +1,4 @@
-/*      $Id: display.c 25371 2007-04-02 19:32:01Z olivier $
+/*      $Id: display.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -88,6 +88,7 @@ myDisplayInitAtoms (DisplayInfo *display_info)
         "_NET_DESKTOP_NAMES",
         "_NET_DESKTOP_VIEWPORT",
         "_NET_FRAME_EXTENTS",
+        "_NET_MOVERESIZE_WINDOW",
         "_NET_NUMBER_OF_DESKTOPS",
         "_NET_REQUEST_FRAME_EXTENTS",
         "_NET_SHOWING_DESKTOP",
@@ -178,6 +179,19 @@ myDisplayInitAtoms (DisplayInfo *display_info)
                           FALSE, display_info->atoms) != 0);
 }
 
+static void
+myDisplayCreateTimestampWin (DisplayInfo *display_info)
+{
+    XSetWindowAttributes attributes;
+
+    attributes.event_mask = PropertyChangeMask;
+    attributes.override_redirect = TRUE;
+    display_info->timestamp_win = 
+        XCreateWindow (display_info->dpy, DefaultRootWindow (display_info->dpy),
+                       -100, -100, 10, 10, 0, 0, CopyFromParent, CopyFromParent,
+                       CWEventMask | CWOverrideRedirect, &attributes);
+}
+
 DisplayInfo *
 myDisplayInit (GdkDisplay *gdisplay)
 {
@@ -309,6 +323,8 @@ myDisplayInit (GdkDisplay *gdisplay)
     display->resize_cursor[CORNER_COUNT + SIDE_BOTTOM] =
         XCreateFontCursor (display->dpy, XC_bottom_side);
 
+    myDisplayCreateTimestampWin (display);
+
     display->xfilter = NULL;
     display->screens = NULL;
     display->clients = NULL;
@@ -340,6 +356,8 @@ myDisplayClose (DisplayInfo *display)
     display->move_cursor = None;
     XFreeCursor (display->dpy, display->root_cursor);
     display->root_cursor = None;
+    XDestroyWindow (display->dpy, display->timestamp_win);
+    display->timestamp_win = None;
 
     if (display->hostname)
     {
@@ -668,82 +686,82 @@ myDisplayGetDefaultScreen (DisplayInfo *display)
     return NULL;
 }
 
-Time
+guint32
 myDisplayUpdateCurrentTime (DisplayInfo *display, XEvent *ev)
 {
-    g_return_val_if_fail (display != NULL, (Time) CurrentTime);
+    g_return_val_if_fail (display != NULL, CurrentTime);
 
     switch (ev->type)
     {
         case KeyPress:
         case KeyRelease:
-            display->current_time = (Time) ev->xkey.time;
+            display->current_time = (guint32) ev->xkey.time;
             break;
         case ButtonPress:
         case ButtonRelease:
-            display->current_time = (Time) ev->xbutton.time;
+            display->current_time = (guint32) ev->xbutton.time;
             break;
         case MotionNotify:
-            display->current_time = (Time) ev->xmotion.time;
+            display->current_time = (guint32) ev->xmotion.time;
             break;
         case EnterNotify:
         case LeaveNotify:
-            display->current_time = (Time) ev->xcrossing.time;
+            display->current_time = (guint32) ev->xcrossing.time;
             break;
         case PropertyNotify:
-            display->current_time = (Time) ev->xproperty.time;
+            display->current_time = (guint32) ev->xproperty.time;
             break;
         case SelectionClear:
-            display->current_time = (Time) ev->xselectionclear.time;
+            display->current_time = (guint32) ev->xselectionclear.time;
             break;
         case SelectionRequest:
-            display->current_time = (Time) ev->xselectionrequest.time;
+            display->current_time = (guint32) ev->xselectionrequest.time;
             break;
         case SelectionNotify:
-            display->current_time = (Time) ev->xselection.time;
+            display->current_time = (guint32) ev->xselection.time;
             break;
         default:
-            display->current_time = (Time) CurrentTime;
+            display->current_time = (guint32) CurrentTime;
             break;
     }
     return display->current_time;
 }
 
-Time
+guint32
 myDisplayGetCurrentTime (DisplayInfo *display)
 {
-    g_return_val_if_fail (display != NULL, (Time) CurrentTime);
+    g_return_val_if_fail (display != NULL, CurrentTime);
 
-    TRACE ("myDisplayGetCurrentTime gives timestamp=%u", (unsigned int) display->current_time);
-    return (Time) display->current_time;
+    TRACE ("myDisplayGetCurrentTime gives timestamp=%u", (guint32) display->current_time);
+    return display->current_time;
 }
 
-Time
-myDisplayGetTime (DisplayInfo * display, Time timestamp)
+guint32
+myDisplayGetTime (DisplayInfo * display, guint32 timestamp)
 {
-    Time time;
+    guint32 time;
 
     time = timestamp;
-    if (time == (Time) CurrentTime)
+    if (time == CurrentTime)
     {
         time = getXServerTime (display);
     }
 
-    TRACE ("myDisplayGetTime gives timestamp=%u", (unsigned int) time);
-    return (time);
+    TRACE ("myDisplayGetTime gives timestamp=%u", (guint32) time);
+    return time;
 }
 
-Time
+guint32
 myDisplayGetLastUserTime (DisplayInfo *display)
 {
-    g_return_val_if_fail (display != NULL, (Time) CurrentTime);
+    g_return_val_if_fail (display != NULL, CurrentTime);
 
-    TRACE ("myDisplayGetLastUserTime gives timestamp=%u", (unsigned int) display->last_user_time);
-    return (Time) display->last_user_time;
+    TRACE ("myDisplayGetLastUserTime gives timestamp=%u", (guint32) display->last_user_time);
+    return display->last_user_time;
 }
 
 void
-myDisplaySetLastUserTime (DisplayInfo *display, Time timestamp)
+myDisplaySetLastUserTime (DisplayInfo *display, guint32 timestamp)
 {
     g_return_if_fail (display != NULL);
 
