@@ -1,4 +1,4 @@
-/*      $Id: display.h 25371 2007-04-02 19:32:01Z olivier $
+/*      $Id: display.h 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -48,6 +48,11 @@
 #define HAVE_NAME_WINDOW_PIXMAP 1
 #endif /* HAVE_NAME_WINDOW_PIXMAP */
 #endif /* COMPOSITE_MAJOR > 0 || COMPOSITE_MINOR >= 2 */
+#if COMPOSITE_MAJOR > 0 || COMPOSITE_MINOR >= 3
+#ifndef HAVE_OVERLAYS
+#define HAVE_OVERLAYS 1
+#endif /* HAVE_OVERLAYS */
+#endif /* COMPOSITE_MAJOR > 0 || COMPOSITE_MINOR >= 3 */
 #endif /* HAVE_COMPOSITOR */
 
 #include <gtk/gtk.h>
@@ -125,6 +130,7 @@ enum
     NET_DESKTOP_NAMES,
     NET_DESKTOP_VIEWPORT,
     NET_FRAME_EXTENTS,
+    NET_MOVERESIZE_WINDOW,
     NET_NUMBER_OF_DESKTOPS,
     NET_REQUEST_FRAME_EXTENTS,
     NET_SHOWING_DESKTOP,
@@ -226,6 +232,7 @@ struct _DisplayInfo
     gboolean quit;
     gboolean reload;
 
+    Window timestamp_win;
     Cursor busy_cursor;
     Cursor move_cursor;
     Cursor root_cursor;
@@ -248,8 +255,8 @@ struct _DisplayInfo
     gint nb_screens;
     gchar* hostname;
 
-    Time current_time;
-    Time last_user_time;
+    guint32 current_time;
+    guint32 last_user_time;
 
     gboolean enable_compositor;
 #ifdef HAVE_RENDER
@@ -285,6 +292,10 @@ struct _DisplayInfo
     gboolean have_name_window_pixmap;
 #endif /* HAVE_NAME_WINDOW_PIXMAP */
 
+#if HAVE_OVERLAYS
+    gboolean have_overlays;
+#endif /* HAVE_OVERLAYS */
+
 #endif /* HAVE_COMPOSITOR */
 };
 
@@ -327,14 +338,14 @@ Client                  *myDisplayGetClientFromXSyncAlarm       (DisplayInfo *,
                                                                  XSyncAlarm);
 #endif /* HAVE_XSYNC */
 ScreenInfo              *myDisplayGetDefaultScreen              (DisplayInfo *);
-Time                     myDisplayUpdateCurrentTime             (DisplayInfo *,
+guint32                  myDisplayUpdateCurrentTime             (DisplayInfo *,
                                                                  XEvent *);
-Time                     myDisplayGetCurrentTime                (DisplayInfo *);
-Time                     myDisplayGetTime                       (DisplayInfo *, 
-                                                                 Time);
-Time                     myDisplayGetLastUserTime               (DisplayInfo *);
+guint32                  myDisplayGetCurrentTime                (DisplayInfo *);
+guint32                  myDisplayGetTime                       (DisplayInfo *,
+                                                                 guint32);
+guint32                  myDisplayGetLastUserTime               (DisplayInfo *);
 void                     myDisplaySetLastUserTime               (DisplayInfo *,
-                                                                 Time);
+                                                                 guint32);
 gboolean                 myDisplayTestXrender                   (DisplayInfo *,
                                                                  gdouble);
 
