@@ -1,4 +1,4 @@
-/*      $Id: events.c 25649 2007-04-27 20:01:12Z olivier $
+/*      $Id: events.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@
                                  PointerMotionMask | \
                                  ButtonPressMask | \
                                  ButtonReleaseMask)
-                  
+
 #define MODIFIER_MASK           (ShiftMask | \
                                  ControlMask | \
                                  AltMask | \
@@ -238,7 +238,7 @@ typeOfClick (ScreenInfo *screen_info, Window w, XEvent * ev, gboolean allow_doub
     passdata.ycurrent = passdata.y;
     passdata.clicks = 1;
     passdata.allow_double_click = allow_double_click;
-    passdata.timeout = g_timeout_add_full (G_PRIORITY_DEFAULT, 
+    passdata.timeout = g_timeout_add_full (G_PRIORITY_DEFAULT,
                                            display_info->dbl_click_time,
                                            (GtkFunction) typeOfClick_break,
                                            (gpointer) &passdata, NULL);
@@ -258,7 +258,7 @@ typeOfClick (ScreenInfo *screen_info, Window w, XEvent * ev, gboolean allow_doub
 static gboolean
 check_button_time (XButtonEvent *ev)
 {
-    static Time last_button_time = (Time) CurrentTime;
+    static guint32 last_button_time = CurrentTime;
 
     if (last_button_time > ev->time)
     {
@@ -304,9 +304,9 @@ reset_timeout (ScreenInfo *screen_info)
     {
         g_source_remove (raise_timeout);
     }
-    raise_timeout = g_timeout_add_full (G_PRIORITY_DEFAULT, 
-                                        screen_info->params->raise_delay, 
-                                        (GtkFunction) raise_cb, 
+    raise_timeout = g_timeout_add_full (G_PRIORITY_DEFAULT,
+                                        screen_info->params->raise_delay,
+                                        (GtkFunction) raise_cb,
                                         NULL, NULL);
 }
 
@@ -487,13 +487,13 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
                 }
                 break;
             case KEY_POPUP_MENU:
-                /* 
-                   We need to release the events here prior to grabbing 
+                /*
+                   We need to release the events here prior to grabbing
                    the keyboard in gtk menu otherwise we end with a dead lock...
                   */
                 XAllowEvents (display_info->dpy, AsyncKeyboard, CurrentTime);
-                show_window_menu (c, frameX (c) + frameLeft (c), 
-                                     frameY (c) + frameTop (c), 
+                show_window_menu (c, frameX (c) + frameLeft (c),
+                                     frameY (c) + frameTop (c),
                                      Button1, GDK_CURRENT_TIME);
                 /* 'nuff for now */
                 return;
@@ -620,7 +620,7 @@ edgeButton (Client * c, int part, XButtonEvent * ev)
     }
 }
 
-static int 
+static int
 edgeGetPart (Client *c, XButtonEvent * ev)
 {
     int part, x_corner_pixels, y_corner_pixels, x_distance, y_distance;
@@ -841,7 +841,7 @@ titleButton (Client * c, int state, XButtonEvent * ev)
 static void
 rootScrollButton (DisplayInfo *display_info, XButtonEvent * ev)
 {
-    static Time lastscroll = (Time) CurrentTime;
+    static guint32 lastscroll = CurrentTime;
     ScreenInfo *screen_info;
 
     if ((ev->time - lastscroll) < 25)  /* ms */
@@ -1361,104 +1361,14 @@ handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
     }
     if (c)
     {
-        gboolean constrained = FALSE;
-        ScreenInfo *screen_info = c->screen_info;
-
-        TRACE ("handleConfigureRequest managed window \"%s\" (0x%lx)", c->name, c->window);
+         TRACE ("handleConfigureRequest managed window \"%s\" (0x%lx)", c->name, c->window);
         if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MOVING_RESIZING))
         {
             /* Sorry, but it's not the right time for configure request */
             return;
         }
-        if (c->type == WINDOW_DESKTOP)
-        {
-            /* Ignore stacking request for DESKTOP windows */
-            ev->value_mask &= ~(CWSibling | CWStackMode);
-        }
-        clientCoordGravitate (c, APPLY, &wc.x, &wc.y);
-        if (FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
-        {
-            GdkRectangle rect;
-            gint monitor_nbr;
-            int cx, cy;
-
-            /* size request from fullscreen windows get fullscreen */
-
-            cx = frameX (c) + (frameWidth (c) / 2);
-            cy = frameY (c) + (frameHeight (c) / 2);
-
-            monitor_nbr = find_monitor_at_point (screen_info->gscr, cx, cy);
-            gdk_screen_get_monitor_geometry (screen_info->gscr, monitor_nbr, &rect);
-
-            wc.x = rect.x;
-            wc.y = rect.y;
-            wc.width = rect.width;
-            wc.height = rect.height;
-
-            ev->value_mask |= (CWX | CWY | CWWidth | CWHeight);
-        }
-        else if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
-                 && (screen_info->params->borderless_maximize))
-        {
-            wc.x = c->x;
-            wc.y = c->y;
-            wc.width = c->width;
-            wc.height = c->height;
-        }
-        /* Clean up buggy requests that set all flags */
-        if ((ev->value_mask & CWX) && (wc.x == c->x))
-        {
-            ev->value_mask &= ~CWX;
-        }
-        if ((ev->value_mask & CWY) && (wc.y == c->y))
-        {
-            ev->value_mask &= ~CWY;
-        }
-        if ((ev->value_mask & CWWidth) && (wc.width == c->width))
-        {
-            ev->value_mask &= ~CWWidth;
-        }
-        if ((ev->value_mask & CWHeight) && (wc.height == c->height))
-        {
-            ev->value_mask &= ~CWHeight;
-        }
-        /* Still a move/resize after cleanup? */
-        if (ev->value_mask & (CWX | CWY | CWWidth | CWHeight))
-        {
-            if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
-            {
-                clientRemoveMaximizeFlag (c);
-            }
-            constrained = TRUE;
-        }
-
-        /* 
-           Let's say that if the client performs a XRaiseWindow, we show the window if focus 
-           stealing prevention is not activated, otherwise we just set the "demands attention"
-           flag...
-         */
-        if ((ev->value_mask & CWStackMode) && (wc.stack_mode == Above) && (wc.sibling == None))
-        {
-            Client *last_raised;
-            
-            last_raised = clientGetLastRaise (screen_info);
-            if (last_raised && (c != last_raised))
-            {
-                if ((screen_info->params->prevent_focus_stealing) && (screen_info->params->activate_action == ACTIVATE_ACTION_NONE))
-                {
-                    ev->value_mask &= ~(CWSibling | CWStackMode);
-                    TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window); 
-                    FLAG_SET (c->flags, CLIENT_FLAG_DEMANDS_ATTENTION);
-                    clientSetNetState (c);
-                }
-                else
-                {
-                    clientActivate (c, getXServerTime (display_info));
-                }
-            }
-        }
-
-        clientConfigure (c, &wc, ev->value_mask, (constrained ? CFG_CONSTRAINED : 0) | CFG_REQUEST);
+        clientAdjustCoordGravity (c, c->gravity, &ev->value_mask, &wc);
+        clientMoveResizeWindow (c, &wc, ev->value_mask);
     }
     else
     {
@@ -1470,7 +1380,7 @@ handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
 static void
 handleEnterNotify (DisplayInfo *display_info, XCrossingEvent * ev)
 {
-    static Time lastresist = (Time) CurrentTime;
+    static guint32 lastresist = CurrentTime;
     ScreenInfo *screen_info;
     Client *c;
     gboolean warp_pointer;
@@ -1680,10 +1590,10 @@ handleFocusIn (DisplayInfo *display_info, XFocusChangeEvent * ev)
     }
 
     if ((ev->window == screen_info->xroot)
-        && ((ev->detail == NotifyDetailNone) 
+        && ((ev->detail == NotifyDetailNone)
             || ((ev->mode == NotifyNormal) && (ev->detail == NotifyInferior))))
     {
-        /* 
+        /*
            Handle unexpected focus transition to root (means that an unknown
            window has vanished and the focus is returned to the root).
          */
@@ -1710,10 +1620,10 @@ handleFocusIn (DisplayInfo *display_info, XFocusChangeEvent * ev)
         clientUpdateFocus (screen_info, c, FOCUS_SORT);
         if ((user_focus != c) && (user_focus != NULL))
         {
-            /* 
+            /*
                Focus stealing prevention:
-               Some apps tend to focus the window directly. If focus stealing prevention is enabled, 
-               we revert the user set focus to the window that we think has focus and then set the 
+               Some apps tend to focus the window directly. If focus stealing prevention is enabled,
+               we revert the user set focus to the window that we think has focus and then set the
                demand attention flag.
 
                Note that focus stealing prevention is ignored between windows of the same group or
@@ -1725,12 +1635,12 @@ handleFocusIn (DisplayInfo *display_info, XFocusChangeEvent * ev)
                 !clientSameGroup (c, user_focus) &&
                 !clientIsTransientOrModalFor (c, user_focus))
             {
-                TRACE ("Setting focus back to \"%s\" (0x%lx)", user_focus->name, user_focus->window); 
+                TRACE ("Setting focus back to \"%s\" (0x%lx)", user_focus->name, user_focus->window);
                 clientSetFocus (user_focus->screen_info, user_focus, getXServerTime (display_info), NO_FOCUS_FLAG);
 
                 if (current_focus)
                 {
-                    TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window); 
+                    TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window);
                     FLAG_SET (c->flags, CLIENT_FLAG_DEMANDS_ATTENTION);
                     clientSetNetState (c);
                 }
@@ -1779,7 +1689,7 @@ handleFocusOut (DisplayInfo *display_info, XFocusChangeEvent * ev)
                 "NotifyDetailNone" :
                 "(unknown)");
 
-    if ((ev->mode == NotifyGrab) || (ev->mode == NotifyUngrab) || 
+    if ((ev->mode == NotifyGrab) || (ev->mode == NotifyUngrab) ||
         (ev->detail == NotifyInferior) || (ev->detail > NotifyNonlinearVirtual))
     {
         /* We're not interested in such notifications */
@@ -1871,19 +1781,19 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
             if (clientCheckTransientWindow (c, w))
             {
                 c->transient_for = w;
-#if 0                
+#if 0
                 /*
                   Java 1.6 updates the WM_TRANSIENT_FOR properties "on-the-fly"
-                  of its windows to maintain the z-order. 
-                  
-                  If we raise the transient then, we clearly have a race 
-                  condition between the WM and Java... And that breaks 
+                  of its windows to maintain the z-order.
+
+                  If we raise the transient then, we clearly have a race
+                  condition between the WM and Java... And that breaks
                   the z-order. Bug #2483.
-                  
+
                   I still think that raising here makes sense, to ensure
                   that the newly promoted transient window is placed above
                   its parent.
-                  
+
                   Chances are that Java 1.6 won't change any time soon (heh,
                   it's not even released yet), so let's adjust the WM to
                   work with Java 1.6...
@@ -1924,7 +1834,7 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
         else if (ev->atom == display_info->atoms[NET_WM_USER_TIME])
         {
             TRACE ("client \"%s\" (0x%lx) has received a NET_WM_USER_TIME notify", c->name, c->window);
-            if (getNetWMUserTime (display_info, c->window, &c->user_time))
+            if (getNetWMUserTime (display_info, c->window, &c->user_time) && (c->user_time != 0))
             {
                 myDisplaySetLastUserTime (display_info, c->user_time);
                 FLAG_SET (c->flags, CLIENT_FLAG_HAS_USER_TIME);
@@ -2021,7 +1931,7 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         if ((ev->message_type == display_info->atoms[WM_CHANGE_STATE]) && (ev->format == 32) && (ev->data.l[0] == IconicState))
         {
             TRACE ("client \"%s\" (0x%lx) has received a WM_CHANGE_STATE event", c->name, c->window);
-            if (!FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED) && CLIENT_CAN_HIDE_WINDOW (c))
+            if (!FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
             {
                 clientHide (c, c->win_workspace, TRUE);
             }
@@ -2089,23 +1999,28 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             TRACE ("client \"%s\" (0x%lx) has received a NET_WM_MOVERESIZE event", c->name, c->window);
             clientNetMoveResize (c, ev);
         }
+        else if ((ev->message_type == display_info->atoms[NET_MOVERESIZE_WINDOW]) && (ev->format == 32))
+        {
+            TRACE ("client \"%s\" (0x%lx) has received a NET_MOVERESIZE_WINDOW event", c->name, c->window);
+            clientNetMoveResizeWindow (c, ev);
+        }
         else if ((ev->message_type == display_info->atoms[NET_ACTIVE_WINDOW]) && (ev->format == 32))
         {
             gboolean source_is_application;
-            Time ev_time;
+            guint32 ev_time;
 
-            ev_time = myDisplayGetTime (display_info, (Time) ev->data.l[1]);
+            ev_time = myDisplayGetTime (display_info, (guint32) ev->data.l[1]);
             source_is_application = (ev->data.l[0] == 1);
 
             TRACE ("client \"%s\" (0x%lx) has received a NET_ACTIVE_WINDOW event", c->name, c->window);
             if (source_is_application)
             {
-                Time current = myDisplayGetLastUserTime (display_info);
+                guint32 current = myDisplayGetLastUserTime (display_info);
 
-                TRACE ("Time of event received is %u, current XServer time is %u", (unsigned int) ev_time, (unsigned int) current);
+                TRACE ("Time of event received is %u, current XServer time is %u", (guint32) ev_time, (guint32) current);
                 if ((screen_info->params->prevent_focus_stealing) && TIMESTAMP_IS_BEFORE(ev_time, current))
                 {
-                    TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window); 
+                    TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window);
                     FLAG_SET (c->flags, CLIENT_FLAG_DEMANDS_ATTENTION);
                     clientSetNetState (c);
                 }
@@ -2139,11 +2054,11 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
              (ev->message_type == display_info->atoms[NET_CURRENT_DESKTOP])) && (ev->format == 32))
         {
             TRACE ("root has received a win_workspace or a NET_CURRENT_DESKTOP event %li", ev->data.l[0]);
-            if ((ev->data.l[0] >= 0) && (ev->data.l[0] < screen_info->workspace_count) && 
+            if ((ev->data.l[0] >= 0) && (ev->data.l[0] < screen_info->workspace_count) &&
                 (ev->data.l[0] != screen_info->current_ws))
             {
-                workspaceSwitch (screen_info, ev->data.l[0], NULL, TRUE, 
-                                 myDisplayGetTime (display_info, (Time) ev->data.l[1]));
+                workspaceSwitch (screen_info, ev->data.l[0], NULL, TRUE,
+                                 myDisplayGetTime (display_info, (guint32) ev->data.l[1]));
             }
         }
         else if (((ev->message_type == display_info->atoms[WIN_WORKSPACE_COUNT]) ||
@@ -2176,10 +2091,10 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         else if ((ev->message_type == display_info->atoms[MANAGER]) && (ev->format == 32))
         {
             Atom selection;
-            
+
             TRACE ("window (0x%lx) has received a MANAGER event", ev->window);
             selection = (Atom) ev->data.l[1];
-            
+
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
             if (selection == screen_info->net_system_tray_selection)
             {
@@ -2201,6 +2116,24 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
     }
 }
 
+static void
+handleSelectionClear (DisplayInfo *display_info, XSelectionClearEvent * ev)
+{
+    ScreenInfo *screen_info;
+
+    TRACE ("entering handleSelectionClear");
+
+    screen_info = myDisplayGetScreenFromWindow (display_info, ev->window);
+    if (screen_info)
+    {
+        if (myScreenCheckWMAtom (screen_info, ev->selection))
+        {
+            TRACE ("root has received a WM_Sn selection event");
+            display_info->quit = TRUE;
+        }
+    }
+}
+
 static void
 handleShape (DisplayInfo *display_info, XShapeEvent * ev)
 {
@@ -2279,7 +2212,6 @@ handleMappingNotify (DisplayInfo *display_info, XMappingEvent * ev)
 static void
 handleXSyncAlarmNotify (DisplayInfo *display_info, XSyncAlarmNotifyEvent * ev)
 {
-    XWindowChanges wc;
     Client *c;
 
     TRACE ("entering handleXSyncAlarmNotify");
@@ -2294,14 +2226,7 @@ handleXSyncAlarmNotify (DisplayInfo *display_info, XSyncAlarmNotifyEvent * ev)
     {
         c->xsync_waiting = FALSE;
         c->xsync_value = ev->counter_value;
-        if (c->xsync_enabled)
-        {
-            wc.x = c->x;
-            wc.y = c->y;
-            wc.width = c->width;
-            wc.height = c->height;
-            clientConfigure (c, &wc, CWX | CWY | CWWidth | CWHeight, NO_CFG_FLAG);
-        }
+        clientXSyncClearTimeout (c);
     }
 }
 #endif /* HAVE_XSYNC */
@@ -2366,6 +2291,9 @@ handleEvent (DisplayInfo *display_info, XEvent * ev)
         case ClientMessage:
             handleClientMessage (display_info, (XClientMessageEvent *) ev);
             break;
+        case SelectionClear:
+            handleSelectionClear (display_info, (XSelectionClearEvent *) ev);
+            break;
         case ColormapNotify:
             handleColormapNotify (display_info, (XColormapEvent *) ev);
             break;
