@@ -1,4 +1,4 @@
-/*      $Id: focus.c 24170 2006-12-22 20:55:02Z olivier $
+/*      $Id: focus.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ clientGetTopMostFocusable (ScreenInfo *screen_info, int layer, Client * exclude)
 }
 
 void
-clientFocusTop (ScreenInfo *screen_info, int layer, Time timestamp)
+clientFocusTop (ScreenInfo *screen_info, int layer, guint32 timestamp)
 {
     ClientPair top_client;
     DisplayInfo *display_info;
@@ -145,7 +145,7 @@ clientFocusNew(Client * c)
     }
     else if ((client_focus) && (prevent_focus_stealing))
     {
-        if (FLAG_TEST (c->flags, CLIENT_FLAG_HAS_STARTUP_TIME) && (c->user_time == (Time) CurrentTime))
+        if (FLAG_TEST (c->flags, CLIENT_FLAG_HAS_STARTUP_TIME) && (c->user_time == CurrentTime))
         {
             TRACE ("Given startup time is 0, not focusing");
             give_focus = FALSE;
@@ -484,7 +484,7 @@ clientUpdateFocus (ScreenInfo *screen_info, Client * c, unsigned short flags)
 }
 
 void
-clientSetFocus (ScreenInfo *screen_info, Client * c, Time timestamp, unsigned short flags)
+clientSetFocus (ScreenInfo *screen_info, Client * c, guint32 timestamp, unsigned short flags)
 {
     DisplayInfo *display_info;
     Client *c2;
