@@ -1,4 +1,4 @@
-/*      $Id: hints.c 25831 2007-06-21 22:28:04Z olivier $
+/*      $Id: hints.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -397,7 +397,7 @@ setGnomeProtocols (DisplayInfo *display_info, Window root, Window w)
 void
 setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
 {
-    Atom atoms[64];
+    Atom atoms[ATOM_COUNT];
     unsigned long data[1];
     int i;
 
@@ -412,6 +412,7 @@ setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
     atoms[i++] = display_info->atoms[NET_DESKTOP_NAMES];
     atoms[i++] = display_info->atoms[NET_DESKTOP_VIEWPORT];
     atoms[i++] = display_info->atoms[NET_FRAME_EXTENTS];
+    atoms[i++] = display_info->atoms[NET_MOVERESIZE_WINDOW];
     atoms[i++] = display_info->atoms[NET_NUMBER_OF_DESKTOPS];
     atoms[i++] = display_info->atoms[NET_REQUEST_FRAME_EXTENTS];
     atoms[i++] = display_info->atoms[NET_SHOWING_DESKTOP];
@@ -463,7 +464,7 @@ setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
     atoms[i++] = display_info->atoms[NET_STARTUP_ID];
 #endif
-    g_assert (i < 64);
+    g_assert (i < ATOM_COUNT);
     data[0] = check_win;
     XChangeProperty (display_info->dpy, root, display_info->atoms[NET_SUPPORTED],
                      XA_ATOM, 32, PropModeReplace, (unsigned char *) atoms, i);
@@ -611,7 +612,7 @@ setUTF8StringHint (DisplayInfo *display_info, Window w, int atom_id, const gchar
 
     XChangeProperty (display_info->dpy, w, display_info->atoms[atom_id],
                      display_info->atoms[UTF8_STRING], 8, PropModeReplace,
-                     (unsigned char *) val, strlen (val) + 1);
+                     (unsigned char *) val, strlen (val));
 }
 
 void
@@ -946,7 +947,7 @@ getClientLeader (DisplayInfo *display_info, Window window)
 }
 
 gboolean
-getNetWMUserTime (DisplayInfo *display_info, Window window, Time *time)
+getNetWMUserTime (DisplayInfo *display_info, Window window, guint32 *time)
 {
     Atom actual_type;
     int actual_format;
@@ -965,12 +966,12 @@ getNetWMUserTime (DisplayInfo *display_info, Window window, Time *time)
         if ((data) && (actual_type == XA_CARDINAL)
             && (nitems == 1) && (bytes_after == 0))
         {
-            *time = *((long *) data);
+            *time = *((guint32 *) data);
             XFree (data);
             return TRUE;
         }
     }
-    *time = (Time) 0;
+    *time = 0;
 
     return FALSE;
 }
@@ -1126,7 +1127,7 @@ gboolean
 setXAtomManagerOwner (DisplayInfo *display_info, Atom atom, Window root, Window w)
 {
     XClientMessageEvent ev;
-    Time server_time;
+    guint32 server_time;
     int status;
 
     g_return_val_if_fail (root != None, FALSE);
@@ -1170,7 +1171,6 @@ setAtomIdManagerOwner (DisplayInfo *display_info, int atom_id, Window root, Wind
 void
 updateXserverTime (DisplayInfo *display_info)
 {
-    ScreenInfo *screen_info;
     char c = '\0';
 
     g_return_if_fail (display_info);
@@ -1181,27 +1181,27 @@ updateXserverTime (DisplayInfo *display_info)
                      8, PropModeReplace, (unsigned char *) &c, 1);
 }
 
-Time
+guint32
 getXServerTime (DisplayInfo *display_info)
 {
     ScreenInfo *screen_info;
     XEvent xevent;
-    Time timestamp;
+    guint32 timestamp;
 
-    g_return_val_if_fail (display_info, (Time) CurrentTime);
+    g_return_val_if_fail (display_info, CurrentTime);
     timestamp = myDisplayGetCurrentTime (display_info);
-    if (timestamp == (Time) CurrentTime)
+    if (timestamp == CurrentTime)
     {
         screen_info = myDisplayGetDefaultScreen (display_info);
-        g_return_val_if_fail (screen_info,  (Time) CurrentTime);
+        g_return_val_if_fail (screen_info,  CurrentTime);
 
         TRACE ("getXServerTime: Using X server roundtrip");
         updateXserverTime (display_info);
         XWindowEvent (display_info->dpy, display_info->timestamp_win, PropertyChangeMask, &xevent);
-        timestamp = (Time) myDisplayUpdateCurrentTime (display_info, &xevent);
+        timestamp = myDisplayUpdateCurrentTime (display_info, &xevent);
     }
 
-    TRACE ("getXServerTime gives timestamp=%u", (unsigned int) timestamp);
+    TRACE ("getXServerTime gives timestamp=%u", timestamp);
     return timestamp;
 }
 
