@@ -1,4 +1,4 @@
-/*      $Id: hints.h 25831 2007-06-21 22:28:04Z olivier $
+/*      $Id: hints.h 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -240,7 +240,7 @@ Window                   getClientLeader                        (DisplayInfo *,
                                                                  Window);
 gboolean                 getNetWMUserTime                       (DisplayInfo *, 
                                                                  Window, 
-                                                                 Time *);
+                                                                 guint32 *);
 gboolean                 getClientID                            (DisplayInfo *, 
                                                                  Window, 
                                                                  gchar **);
@@ -270,7 +270,7 @@ gboolean                 setAtomIdManagerOwner                  (DisplayInfo *,
                                                                  Window , 
                                                                  Window);
 void                     updateXserverTime                      (DisplayInfo *);
-Time                     getXServerTime                         (DisplayInfo *);
+guint32                  getXServerTime                         (DisplayInfo *);
 
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
 gboolean                 checkKdeSystrayWindow                  (DisplayInfo *, 
