@@ -1,34 +1,35 @@
-/*      $Id: main.c 22954 2006-08-30 19:41:26Z olivier $
- 
+/*      $Id: main.c 28384 2008-10-23 17:18:16Z olivier $
+
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
         any later version.
- 
+
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
         MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
         GNU General Public License for more details.
- 
+
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- 
+
         oroborus - (c) 2001 Ken Lynch
         xfwm4    - (c) 2002-2006 Olivier Fourdan
- 
+
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <X11/X.h>
 #include <X11/Xlib.h>
 #include <glib.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <libxfce4util/libxfce4util.h> 
+#include <libxfce4util/libxfce4util.h>
 #include <libxfcegui4/libxfcegui4.h>
 
 #include <sys/stat.h>
@@ -76,6 +77,12 @@
 #define MAIN_EVENT_MASK BASE_EVENT_MASK
 #endif /* HAVE_COMPOSITOR */
 
+enum {
+    COMPOSITOR_MODE_OFF = 0,
+    COMPOSITOR_MODE_AUTO,
+    COMPOSITOR_MODE_MANUAL
+};
+
 #ifndef DEBUG
 /* For what, IEEE Std 1003.1-2001, Section 12.2, Utility Syntax Guidelines.*/
 static char revision[]="@(#)$ " PACKAGE " version " VERSION " revision " REVISION " $";
@@ -87,9 +94,9 @@ static void
 cleanUp (void)
 {
     GSList *screens;
-    
+
     g_return_if_fail (display_info);
-    
+
     TRACE ("entering cleanUp");
 
     eventFilterClose (display_info->xfilter);
@@ -101,7 +108,7 @@ cleanUp (void)
     }
     sn_close_display ();
     sessionFreeWindowStates ();
-    
+
     myDisplayClose (display_info);
     g_free (display_info);
     display_info = NULL;
@@ -141,11 +148,11 @@ ensure_basedir_spec (void)
     const char *name;
 
     /* test if new directory is there */
-    
-    new = xfce_resource_save_location (XFCE_RESOURCE_CONFIG, 
-                                       "xfce4" G_DIR_SEPARATOR_S "xfwm4", 
+
+    new = xfce_resource_save_location (XFCE_RESOURCE_CONFIG,
+                                       "xfce4" G_DIR_SEPARATOR_S "xfwm4",
                                        FALSE);
-    
+
     if (g_file_test (new, G_FILE_TEST_IS_DIR))
     {
         g_free (new);
@@ -153,7 +160,7 @@ ensure_basedir_spec (void)
     }
 
     error = NULL;
-    if (!xfce_mkdirhier(new, 0700, &error)) 
+    if (!xfce_mkdirhier(new, 0700, &error))
     {
         g_warning("Unable to create config dir %s: %s", new, error->message);
         g_error_free (error);
@@ -164,7 +171,7 @@ ensure_basedir_spec (void)
     g_free (new);
 
     /* copy xfwm4rc */
-    
+
     old = xfce_get_userfile ("xfwm4rc", NULL);
 
     if (g_file_test (old, G_FILE_TEST_EXISTS))
@@ -178,11 +185,11 @@ ensure_basedir_spec (void)
         w = fopen (new, "w");
 
         g_free (new);
-        
+
         if (w && r)
         {
             int c;
-            
+    
             while ((c = getc (r)) != EOF)
             {
                 putc (c, w);
@@ -199,13 +206,13 @@ ensure_basedir_spec (void)
             fclose (w);
         }
     }
-    
+
     g_free (old);
 
     /* copy saved session data */
-    
+
     new = xfce_resource_save_location (XFCE_RESOURCE_CACHE, "sessions", FALSE);
-    if (!xfce_mkdirhier(new, 0700, &error)) 
+    if (!xfce_mkdirhier(new, 0700, &error))
     {
         g_warning("Unable to create session dir %s: %s", new, error->message);
         g_error_free (error);
@@ -231,7 +238,7 @@ ensure_basedir_spec (void)
             if (w && r)
             {
                 int c;
-                
+        
                 while ((c = getc (r)) != EOF)
                     putc (c, w);
             }
@@ -256,18 +263,18 @@ print_usage (void)
 #ifdef HAVE_COMPOSITOR
              "[--compositor=off|on|auto] "
 #endif
-             "[--daemon] [--version|-V] [--help|-H]\n", PACKAGE);
+             "[--daemon] [--replace] [--version|-V] [--help|-H]\n", PACKAGE);
 }
 
 static void
 print_version (void)
 {
-    g_print ("\tThis is %s version %s (revision %s) for Xfce %s\n", 
+    g_print ("\tThis is %s version %s (revision %s) for Xfce %s\n",
                     PACKAGE, VERSION, REVISION, xfce_version_string());
-    g_print ("\tReleased under the terms of the GNU General Public License.\n"); 
-    g_print ("\tCompiled against GTK+-%d.%d.%d, ", 
+    g_print ("\tReleased under the terms of the GNU General Public License.\n");
+    g_print ("\tCompiled against GTK+-%d.%d.%d, ",
                     GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION);
-    g_print ("using GTK+-%d.%d.%d.\n", 
+    g_print ("using GTK+-%d.%d.%d.\n",
                     gtk_major_version, gtk_minor_version, gtk_micro_version);
     g_print ("\n");
     g_print ("\tBuild configuration and supported features:\n");
@@ -277,41 +284,49 @@ print_version (void)
     g_print ("Yes\n");
 #else
     g_print ("No\n");
-#endif    
+#endif
+
+    g_print ("\t- XSync support:                                ");
+#ifdef HAVE_XSYNC
+    g_print ("Yes\n");
+#else
+    g_print ("No\n");
+#endif
 
     g_print ("\t- Render support:                               ");
 #ifdef HAVE_RENDER
     g_print ("Yes\n");
 #else
     g_print ("No\n");
-#endif    
+#endif
 
     g_print ("\t- Xrandr support:                               ");
 #ifdef HAVE_RANDR
     g_print ("Yes\n");
 #else
     g_print ("No\n");
-#endif    
+#endif
 
     g_print ("\t- Embedded compositor:                          ");
 #ifdef HAVE_COMPOSITOR
     g_print ("Yes\n");
 #else
     g_print ("No\n");
-#endif    
+#endif
+
     g_print ("\t- KDE systray proxy (deprecated):               ");
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
     g_print ("Yes\n");
 #else
     g_print ("No\n");
-#endif    
+#endif
 }
 
 #ifdef HAVE_COMPOSITOR
 static gint
 get_default_compositor (DisplayInfo *display_info)
 {
-    /* 
+    /*
      * Don't even check for the render speed if there is no compositor.
      */
     if (!display_info->enable_compositor)
@@ -319,7 +334,7 @@ get_default_compositor (DisplayInfo *display_info)
         return 0;
     }
 
-    /* 
+    /*
      * Check if the XServer is black listed.
      */
     if (!compositorTestServer (display_info))
@@ -329,7 +344,7 @@ get_default_compositor (DisplayInfo *display_info)
     }
 
 #if 0
-    /* 
+    /*
      * Test if the XRender implementation is fast enough for the
      * compositor.
      */
@@ -350,22 +365,22 @@ parse_compositor (const gchar *s)
     gchar *rvalue;
     gint retval;
 
-    retval = 2;
+    retval = COMPOSITOR_MODE_MANUAL;
     rvalue = strrchr (s, '=');
     if (rvalue)
     {
         rvalue++;
         if (!strcmp (rvalue, "off"))
         {
-            retval = 0;
+            retval = COMPOSITOR_MODE_OFF;
         }
         else if (!strcmp (rvalue, "auto"))
         {
-            retval = 1;
+            retval = COMPOSITOR_MODE_AUTO;
         }
         else if (!strcmp (rvalue, "on"))
         {
-            retval = 2;
+            retval = COMPOSITOR_MODE_MANUAL;
         }
         else
         {
@@ -378,44 +393,43 @@ parse_compositor (const gchar *s)
 #endif /* HAVE_COMPOSITOR */
 
 static int
-initialize (int argc, char **argv, gint compositor_mode)
+initialize (int argc, char **argv, gint compositor_mode, gboolean replace_wm)
 {
     struct sigaction act;
     long ws;
     gint i, nscreens;
-    
+
     TRACE ("entering initialize");
-    
-    xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+
+    xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
 
     gtk_init (&argc, &argv);
 
-    DBG ("xfwm4 starting, using GTK+-%d.%d.%d", gtk_major_version, 
+    DBG ("xfwm4 starting, using GTK+-%d.%d.%d", gtk_major_version,
          gtk_minor_version, gtk_micro_version);
 
     ensure_basedir_spec ();
-    
-    initMenuEventWin ();
-    clientClearFocus ();
 
+    initMenuEventWin ();
+    clientClearFocus (NULL);
     display_info = myDisplayInit (gdk_display_get_default ());
-    
+
 #ifdef HAVE_COMPOSITOR
-    if (compositor_mode < 0)
+    if (compositor_mode < COMPOSITOR_MODE_OFF)
     {
         compositor_mode = get_default_compositor (display_info);
     }
-    
+
     /* Disabling compositor from command line */
     if (!compositor_mode)
     {
         display_info->enable_compositor = FALSE;
     }
-    compositorSetCompositeMode (display_info, (compositor_mode == 2));
+    compositorSetCompositeMode (display_info, (compositor_mode == COMPOSITOR_MODE_MANUAL));
 #else /* HAVE_COMPOSITOR */
     display_info->enable_compositor = FALSE;
 #endif /* HAVE_COMPOSITOR */
-    
+
     initModifiers (display_info->dpy);
 
     act.sa_handler = handleSignal;
@@ -426,43 +440,53 @@ initialize (int argc, char **argv, gint compositor_mode)
     sigaction (SIGUSR1, &act, NULL);
     sigaction (SIGSEGV, &act, NULL);
 
-    nscreens = gdk_display_get_n_screens(display_info->gdisplay);
-    for(i = 0; i < nscreens; i++) 
+    nscreens = gdk_display_get_n_screens (display_info->gdisplay);
+    for(i = 0; i < nscreens; i++)
     {
         ScreenInfo *screen_info;
         GdkScreen *gscr;
-        
-        gscr = gdk_display_get_screen(display_info->gdisplay, i);
-        screen_info = myScreenInit (display_info, gscr, MAIN_EVENT_MASK);
+
+        gscr = gdk_display_get_screen (display_info->gdisplay, i);
+        screen_info = myScreenInit (display_info, gscr, MAIN_EVENT_MASK, replace_wm);
 
         if (!screen_info)
         {
             continue;
         }
-        
+
         if (!initSettings (screen_info))
         {
             return -2;
         }
-        
-        if (compositor_mode)
+
+        if (compositor_mode == COMPOSITOR_MODE_AUTO)
+        {
+            compositorManageScreen (screen_info);
+        }
+        else if (compositor_mode == COMPOSITOR_MODE_MANUAL)
         {
             gboolean xfwm4_compositor;
-            
-            xfwm4_compositor = (compositor_mode > 1);
+
+            xfwm4_compositor = TRUE;
             if (screen_info->params->use_compositing)
             {
+                /* Enable compositor if "use compositing" is enabled */
                 xfwm4_compositor = compositorManageScreen (screen_info);
             }
+            /* 
+               The user may want to use the manual compositing, but the installed
+               system may not support it, so we need to double check, to see if
+               initialization of the compositor was successful.
+             */
             if (xfwm4_compositor)
             {
-                /* 
+                /*
                    Acquire selection on XFWM4_COMPOSITING_MANAGER to advertise our own
                    compositing manager (used by WM tweaks to determine whether or not
                    show the "compositor" tab.
                  */
-                setAtomIdManagerOwner (display_info, XFWM4_COMPOSITING_MANAGER, 
-                                     screen_info->xroot, screen_info->xfwm4_win);
+                setAtomIdManagerOwner (display_info, XFWM4_COMPOSITING_MANAGER,
+                                       screen_info->xroot, screen_info->xfwm4_win);
             }
         }
 
@@ -478,13 +502,13 @@ initialize (int argc, char **argv, gint compositor_mode)
         setUTF8StringHint (display_info, screen_info->xfwm4_win, NET_WM_NAME, "Xfwm4");
         setNetSupportedHint (display_info, screen_info->xroot, screen_info->xfwm4_win);
         initNetDesktopInfo (display_info, screen_info->xroot, screen_info->current_ws,
-                                   screen_info->width, 
+                                   screen_info->width,
                                    screen_info->height);
         workspaceUpdateArea (screen_info);
         XSetInputFocus (display_info->dpy, screen_info->xfwm4_win, RevertToPointerRoot, CurrentTime);
 
         clientFrameAll (screen_info);
-        
+
         initGtkCallbacks (screen_info);
 
         XDefineCursor (display_info->dpy, screen_info->xroot, myDisplayGetCursorRoot(display_info));
@@ -505,6 +529,7 @@ int
 main (int argc, char **argv)
 {
     gboolean daemon_mode;
+    gboolean replace_wm;
     gint compositor;
     int status;
     int i;
@@ -512,6 +537,7 @@ main (int argc, char **argv)
     DBG ("xfwm4 starting");
 
     daemon_mode = FALSE;
+    replace_wm = FALSE;
     compositor = -1;
     for (i = 1; i < argc; i++)
     {
@@ -525,20 +551,24 @@ main (int argc, char **argv)
             compositor = parse_compositor (argv[i]);
         }
 #endif /* HAVE_COMPOSITOR */
-        else if (!strcmp(argv[i], "--version") || !strcmp(argv[i], "-V"))
+        else if (!strcmp (argv[i], "--replace"))
+        {
+            replace_wm = TRUE;
+        }
+        else if (!strcmp (argv[i], "--version") || !strcmp (argv[i], "-V"))
         {
             print_version ();
-	    exit (0);
+            exit (0);
         }
-        else if (!strcmp(argv[i], "--help") || !strcmp(argv[i], "-H"))
+        else if (!strcmp (argv[i], "--help") || !strcmp (argv[i], "-H"))
         {
             print_usage ();
-	    exit (0);
+            exit (0);
         }
     }
 
-    status = initialize (argc, argv, compositor);
-    /* 
+    status = initialize (argc, argv, compositor, replace_wm);
+    /*
        status  < 0   =>   Error, cancel execution
        status == 0   =>   Run w/out session manager
        status == 1   =>   Connected to session manager
@@ -557,9 +587,9 @@ main (int argc, char **argv)
             if (daemon_mode)
             {
 #ifdef HAVE_DAEMON
-                if (daemon(TRUE, TRUE) < 0) 
+                if (daemon (TRUE, TRUE) < 0)
                 {
-                        g_warning("Failed to enter daemon mode: %s", g_strerror(errno));
+                        g_warning ("Failed to enter daemon mode: %s", g_strerror(errno));
                         exit(EXIT_FAILURE);
                 }
 #else /* !HAVE_DAEMON */
