@@ -1,4 +1,4 @@
-/*      $Id: menu.c 23128 2006-09-11 20:39:40Z olivier $
+/*      $Id: menu.c 28351 2008-10-21 21:23:05Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include <libxfce4util/libxfce4util.h>
 
 #include "event_filter.h"
+#include "misc.h"
 #include "menu.h"
 
 static GtkWidget *menu_open = NULL;
@@ -88,6 +89,8 @@ popup_position_func (GtkMenu * menu, gint * x, gint * y, gboolean * push_in,
 {
     GtkRequisition req;
     GdkPoint *pos;
+    gint monitor;
+    GdkScreen *screen;
 
     pos = user_data;
 
@@ -111,6 +114,11 @@ popup_position_func (GtkMenu * menu, gint * x, gint * y, gboolean * push_in,
     {
         *y = (gdk_screen_height () - req.height) / 2;
     }
+
+    screen = gtk_widget_get_screen (GTK_WIDGET(menu));
+    monitor = find_monitor_at_point (screen, *x, *y);
+    gtk_menu_set_monitor (GTK_MENU (menu), monitor);
+
     g_free (user_data);
 }
 
