@@ -1,4 +1,4 @@
-/*      $Id: misc.c 25048 2007-03-01 21:31:43Z olivier $
+/*      $Id: misc.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -104,7 +104,7 @@ createGC (ScreenInfo *screen_info, char *col, int func, XFontStruct * font,
 }
 
 void
-sendClientMessage (ScreenInfo *screen_info, Window w, int atom_id, Time timestamp)
+sendClientMessage (ScreenInfo *screen_info, Window w, int atom_id, guint32 timestamp)
 {
     DisplayInfo *display_info;
     XClientMessageEvent ev;
@@ -124,7 +124,7 @@ sendClientMessage (ScreenInfo *screen_info, Window w, int atom_id, Time timestam
 }
 
 void
-sendRootMessage (ScreenInfo *screen_info, int atom_id, long value, Time timestamp)
+sendRootMessage (ScreenInfo *screen_info, int atom_id, long value, guint32 timestamp)
 {
     DisplayInfo *display_info;
     XClientMessageEvent ev;
