@@ -1,4 +1,4 @@
-/*      $Id: netwm.c 26160 2007-10-20 19:29:21Z olivier $
+/*      $Id: netwm.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ clientSetNetState (Client * c)
         TRACE ("clientSetNetState : skip_taskbar");
         data[i++] = display_info->atoms[NET_WM_STATE_SKIP_TASKBAR];
     }
-    if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
+    if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED))
     {
         TRACE ("clientSetNetState : maximize vert + horiz");
         data[i++] = display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ];
@@ -608,7 +608,7 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
     event->xbutton.button = button;
     event->xbutton.x_root = event->xkey.x_root = x_root;
     event->xbutton.y_root = event->xkey.y_root = y_root;
-    event->xbutton.time = event->xkey.time = myDisplayGetCurrentTime (display_info);
+    event->xbutton.time = event->xkey.time = (Time) myDisplayGetCurrentTime (display_info);
 
     switch (action)
     {
@@ -672,7 +672,7 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
             resize = FALSE; /* Move */
             break;
     }
-    
+
     if (!FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
     {
         if (resize && FLAG_TEST_ALL (c->xfwm_flags, XFWM_FLAG_HAS_RESIZE | XFWM_FLAG_IS_RESIZABLE))
@@ -686,6 +686,39 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
     }
 }
 
+void
+clientNetMoveResizeWindow (Client * c, XClientMessageEvent * ev)
+{
+    XWindowChanges wc;
+    unsigned long mask;
+    int gravity;
+
+    g_return_if_fail (c != NULL);
+    TRACE ("entering clientNetMoveResizeWindow");
+    TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
+
+    if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MOVING_RESIZING))
+    {
+        /* not allowed */
+        return;
+    }
+
+    gravity = (ev->data.l[0] & 0xff);
+    if (!gravity)
+    {
+        gravity = c->gravity;
+    }
+
+    wc.x = ev->data.l[1];
+    wc.y = ev->data.l[2];
+    wc.width = ev->data.l[3];
+    wc.height = ev->data.l[4];
+    mask = (ev->data.l[0] & 0xf00) >> 8;
+
+    clientAdjustCoordGravity (c, gravity, &mask, &wc);
+    clientMoveResizeWindow (c, &wc, mask);
+}
+
 void
 clientUpdateFullscreenState (Client * c)
 {
