@@ -1,4 +1,4 @@
-/*      $Id: placement.c 25779 2007-06-03 15:33:52Z olivier $
+/*      $Id: placement.c 26966 2008-05-17 08:22:17Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -390,7 +390,7 @@ clientConstrainPos (Client * c, gboolean show_full)
             frame_y = frameY (c);
             ret |= CLIENT_CONSTRAINED_BOTTOM;
         }
-        if ((frame_y < disp_y) && (frame_y >= disp_y - frame_top))
+        if ((frame_y <= disp_y) && (frame_y >= disp_y - frame_top))
         {
             c->y = disp_y + frame_top;
             frame_y = frameY (c);
