@@ -1,19 +1,19 @@
-/*      $Id: poswin.h 19935 2006-02-18 08:21:05Z olivier $
- 
+/*      $Id: poswin.h 23704 2006-11-04 22:36:42Z olivier $
+
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
         the Free Software Foundation; either version 2, or (at your option)
         any later version.
- 
+
         This program is distributed in the hope that it will be useful,
         but WITHOUT ANY WARRANTY; without even the implied warranty of
         MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
         GNU General Public License for more details.
- 
+
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
         Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- 
+
         xfwm4    - (c) 2002-2006 Olivier Fourdan
           based on a patch from Joshua Blanton <jblanton@irg.cs.ohiou.edu>
  */
@@ -38,10 +38,11 @@ struct _Poswin
     GtkWidget *label;
 };
 
-Poswin *poswinCreate (GdkScreen *);
-void poswinSetPosition (Poswin * poswin,  Client *c);
-void poswinDestroy (Poswin * poswin);
-void poswinShow (Poswin * poswin);
-void poswinHide(Poswin * poswin);
+Poswin                  *poswinCreate                           (GdkScreen *);
+void                     poswinSetPosition                      (Poswin *, 
+                                                                 Client *);
+void                     poswinDestroy                          (Poswin *);
+void                     poswinShow                             (Poswin *);
+void                     poswinHide                             (Poswin *);
 
 #endif /* INC_POSWIN_H */
