@@ -1,4 +1,4 @@
-/*      $Id: startup_notification.c 23128 2006-09-11 20:39:40Z olivier $
+/*      $Id: startup_notification.c 28362 2008-10-22 19:58:39Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -280,12 +280,12 @@ sn_client_startup_properties (Client * c)
     if (sequence != NULL)
     {
         int workspace;
-        Time timestamp;
+        guint32 timestamp;
 
         /* Set initial time */
         timestamp = sn_startup_sequence_get_timestamp (sequence);
         TRACE ("Given startup time: %u", (unsigned int) timestamp);
-        if ((c->user_time == (Time) 0) || TIMESTAMP_IS_BEFORE(c->user_time, timestamp))
+        if ((c->user_time == 0) || TIMESTAMP_IS_BEFORE(c->user_time, timestamp))
         {
             c->user_time = timestamp;
             myDisplaySetLastUserTime (screen_info->display_info, c->user_time);
