@@ -1,4 +1,4 @@
-/*      $Id: transients.c 25409 2007-04-06 19:34:10Z olivier $
+/*      $Id: transients.c 25620 2007-04-20 21:30:53Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -109,7 +109,12 @@ clientIsTransientFor (Client * c1, Client * c2)
         {
             return (c1->transient_for == c2->window);
         }
-        else if (c2->transient_for != c2->screen_info->xroot)
+        /*
+         * Transients for group shouldn't apply to other transients, or 
+         * it breaks stacking for some apps, noticeably mozilla "save as" 
+         * dialog...
+         */
+        else if (c2->transient_for == None)
         {
             return (clientSameGroup (c1, c2));
         }
